﻿using System;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.DesktopEdition;


namespace CSharpWinformsSamples
{
    public class DisplayShapeMap : UserControl
    {
        public DisplayShapeMap()
        {
            InitializeComponent();
        }

        private void DisplayMap_Load(object sender, EventArgs e)
        {
            //Gets the GPS coordinates in Longitude and latitude.

            double GPSlatitude = 21.0;

            double GPSlongitude = 39.0;

            //Converts the Longitude/Latitude coordinates to match Spherical Mercator World Map Kit.

            Proj4Projection proj4 = new Proj4Projection();

            proj4.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(4326); //WGS84(Longitude/Latitude)

            proj4.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString(); //Spherical Mercator projection(Google Map, Bing Map etc)

            proj4.Open();

            Vertex GPSvertex_SphericalMercator = proj4.ConvertToExternalProjection(GPSlongitude, GPSlatitude);

            proj4.Close();

            PointShape GPSpointShape = new PointShape(GPSvertex_SphericalMercator);

            //Creates the circle with 0.8 kilometers of radius.

            EllipseShape ellipseShape = new EllipseShape(GPSpointShape, 0.1, GeographyUnit.Feet, DistanceUnit.Kilometer);

            InMemoryFeatureLayer inMemoryFeatureLayer = new InMemoryFeatureLayer();

            //Sets the symbol as black outline and semi transparent red.

            inMemoryFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(150, GeoColor.StandardColors.Red), GeoColor.StandardColors.Black, 2);

            inMemoryFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.StandardColors.Red, 8);

            inMemoryFeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            inMemoryFeatureLayer.InternalFeatures.Add(new Feature(ellipseShape));

            inMemoryFeatureLayer.InternalFeatures.Add(new Feature(GPSpointShape));

            //winformsMap1.Overlays.Remove("GFOverlay");

            LayerOverlay pointOverlay = new LayerOverlay();

            pointOverlay.Layers.Add("GFLayer", inMemoryFeatureLayer);

            winformsMap1.Overlays.Add("GFOverlay", pointOverlay);

            inMemoryFeatureLayer.Open();

            winformsMap1.CurrentExtent = inMemoryFeatureLayer.GetBoundingBox();

            inMemoryFeatureLayer.Close();

            winformsMap1.Refresh();
        }


        private WinformsMap winformsMap1;

        #region Component Designer generated code

        private System.ComponentModel.IContainer components = null;

        /// <summary> 
        /// Clean up any resources being used.
        /// </summary>
        /// <param name="disposing">true if managed resources should be disposed; otherwise, false.</param>
        protected override void Dispose(bool disposing)
        {
            if (disposing && (components != null))
            {
                components.Dispose();
            }
            base.Dispose(disposing);
        }

        /// <summary> 
        /// Required method for Designer support - do not modify 
        /// the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
            ThinkGeo.MapSuite.DesktopEdition.EditInteractiveOverlay editInteractiveOverlay1 = new ThinkGeo.MapSuite.DesktopEdition.EditInteractiveOverlay();
            ThinkGeo.MapSuite.DesktopEdition.ExtentInteractiveOverlay extentInteractiveOverlay1 = new ThinkGeo.MapSuite.DesktopEdition.ExtentInteractiveOverlay();
            ThinkGeo.MapSuite.DesktopEdition.TrackInteractiveOverlay trackInteractiveOverlay1 = new ThinkGeo.MapSuite.DesktopEdition.TrackInteractiveOverlay();
            this.winformsMap1 = new ThinkGeo.MapSuite.DesktopEdition.WinformsMap();
            this.SuspendLayout();
            // 
            // winformsMap1
            // 
            this.winformsMap1.BackColor = System.Drawing.Color.Gray;
            this.winformsMap1.Dock = System.Windows.Forms.DockStyle.Fill;
            editInteractiveOverlay1.IsVisible = true;
            editInteractiveOverlay1.Name = null;
            this.winformsMap1.EditOverlay = editInteractiveOverlay1;
            extentInteractiveOverlay1.IsVisible = true;
            extentInteractiveOverlay1.Name = null;
            this.winformsMap1.ExtentOverlay = extentInteractiveOverlay1;
            this.winformsMap1.Location = new System.Drawing.Point(0, 0);
            this.winformsMap1.MapUnit = ThinkGeo.MapSuite.Core.GeographyUnit.DecimalDegree;
            this.winformsMap1.MaximumScale = 80000000000000;
            this.winformsMap1.MinimumScale = 200;
            this.winformsMap1.Name = "winformsMap1";
            this.winformsMap1.MapResizeMode = ThinkGeo.MapSuite.Core.MapResizeMode.PreserveScale;
            this.winformsMap1.Size = new System.Drawing.Size(740, 528);
            this.winformsMap1.TabIndex = 0;
            this.winformsMap1.Text = "winformsMap1";
            trackInteractiveOverlay1.IsVisible = true;
            trackInteractiveOverlay1.Name = null;
            trackInteractiveOverlay1.TrackMode = ThinkGeo.MapSuite.DesktopEdition.TrackMode.None;
            this.winformsMap1.TrackOverlay = trackInteractiveOverlay1;
            this.winformsMap1.ZoomLevelSnapping = ThinkGeo.MapSuite.DesktopEdition.ZoomLevelSnappingMode.Default;
            this.winformsMap1.ExtentOverlay.ZoomPercentage = 40;
            // 
            // DisplayShapeMap
            // 
            this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 13F);
            this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
            this.Controls.Add(this.winformsMap1);
            this.Name = "DisplayShapeMap";
            this.Size = new System.Drawing.Size(740, 528);
            this.Load += new System.EventHandler(this.DisplayMap_Load);
            this.ResumeLayout(false);

        }

        #endregion
    }
}
